==> qtjambi-qt3dinput-debuginfo-linux-x64-5.15.17.jar: sources/QtJambi3DInput/QKeyboardHandler_shell.h <==
#ifndef QKEYBOARDHANDLER_SHELL_H
#define QKEYBOARDHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DInput/qkeyboardhandler.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodecommand.h>
#include <Qt3DCore/qnodecreatedchange.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DCore/qscenechange.h>
#include <Qt3DInput/qkeyboarddevice.h>
#include <Qt3DInput/qkeyevent.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QKeyboardHandler_shell : public Qt3DInput::QKeyboardHandler, public QtJambiShellInterface
{
public:
    QKeyboardHandler_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QKeyboardHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sceneChangeEvent(const QSharedPointer<Qt3DCore::QSceneChange>& change0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyboardHandler_access : public Qt3DInput::QKeyboardHandler
{
    void __qt_sceneChangeEvent_cref_QSharedPointer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject change0);
};

#endif // QKEYBOARDHANDLER_SHELL_H

==> qtjambi-qt3dinput-debuginfo-linux-x64-6.5.3.jar: sources/QtJambi3DInput/QKeyboardHandler_shell.h <==
#ifndef QKEYBOARDHANDLER_SHELL_H
#define QKEYBOARDHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DInput/qkeyboardhandler.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DInput/qkeyboarddevice.h>
#include <Qt3DInput/qkeyevent.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QKeyboardHandler_shell : public Qt3DInput::QKeyboardHandler, public QtJambiShellInterface
{
public:
    QKeyboardHandler_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QKeyboardHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyboardHandler_access : public Qt3DInput::QKeyboardHandler
{
};

#endif // QKEYBOARDHANDLER_SHELL_H
